developerscripttools.RenameModulesScript
========================================

.. abjad-lineage:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript

.. autoclass:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.alias
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.argument_parser
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.formatted_help
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.formatted_usage
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.formatted_version
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.long_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.program_name
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.scripting_group
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.short_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.storage_format
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.version
   :noindex:

Methods
-------

.. automethod:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.process_args
   :noindex:

.. automethod:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.setup_argument_parser
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.__call__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.__eq__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.__ge__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.__gt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.__le__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.__lt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.__ne__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.RenameModulesScript.RenameModulesScript.RenameModulesScript.__repr__
   :noindex:
